<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Activar el plugin',
	'affichage' => 'Visualización',
	'aide_non_disponible' => 'Esta parte de la ayuda en línea aún no está disponible en este idioma.',
	'annuler_recherche' => 'Cancelar la búsqueda',
	'auteur' => 'Autor/a:',
	'avis_acces_interdit' => 'Acceso prohibido.',
	'avis_acces_interdit_prive' => 'No tienes derecho de acceder a la página <b>@exec@</b>.',
	'avis_article_modifie' => 'Atención: @nom_auteur_modif@ ha modificado este artículo hace @date_diff@ minutos',
	'avis_aucun_resultat' => 'Ningún resultado.',
	'avis_base_inaccessible' => 'No se puede conectar a la base de datos @base@.',
	'avis_chemin_invalide_1' => 'Ruta de acceso seleccionada',
	'avis_chemin_invalide_2' => 'no parece válido. Regrese a la página precedente y compruebe las informaciones procuradas.',
	'avis_connexion_echec_1' => 'La conexión con la base de datos ha fallado.',
	'avis_connexion_echec_2' => 'Regresa a la página precedente y verifica las informaciones procuradas.',
	'avis_connexion_echec_3' => '<b>Aviso:</b> En muchos servidores, es necesario <b>solicitar</b> la activación del acceso a la base de datos SQL antes de poder usarla. En caso de no poder conectarse a la base de datos, compruebe que se ha realizado la activación.',
	'avis_connexion_erreur_creer_base' => 'La base de datos no se ha podido crear',
	'avis_connexion_erreur_fichier_cle_manquant_1' => 'La instalación debe ser realizada por un webmaster con una copia de seguridad de las claves y su contraseña', # MODIF
	'avis_connexion_erreur_fichier_cle_manquant_2' => 'La instalación debe ser realizada por un webmaster con una copia de seguridad de las claves', # MODIF
	'avis_connexion_erreur_nom_base' => 'El nombre de la base sólo puede contener letras, dígitos y guiones.',
	'avis_connexion_ldap_echec_1' => 'La conexión al servidor LDAP ha fallado.',
	'avis_connexion_ldap_echec_2' => 'Regrese a la página anterior y compruebe la información procurada.',
	'avis_connexion_ldap_echec_3' => 'Alternativamente, no utilice el soporte LDAP para importar usuarios.', # MODIF
	'avis_deplacement_rubrique' => '¡ATENCIÓN! Esta sección contiene @contient_breves@ breve@scb@. Si la desplaza, active esta casilla de confirmación.',
	'avis_erreur_connexion_mysql' => 'Error de conexión SQL',
	'avis_erreur_creation_compte' => 'No se pudo iniciar la cuenta',
	'avis_espace_interdit' => '<b>Espacio prohibido</b> <div>SPIP ya está instalado.</div>',
	'avis_lecture_noms_bases_1' => 'El programa de instalación no logró leer los nombres de las bases de datos instaladas.',
	'avis_lecture_noms_bases_2' => 'Dos posibilidades: o no hay ninguna base disponible o la función de listado de las bases fue desactivada por razones de seguridad (caso frecuente en muchos hospedajes).',
	'avis_lecture_noms_bases_3' => 'En el segundo caso, es probable que una base que tenga como nombre su identificador de usuario sea utilizable:',
	'avis_non_acces_page' => 'No tiene acceso a esta página.',
	'avis_operation_echec' => 'La operación ha fallado.',
	'avis_operation_impossible' => 'Operación imposible',
	'avis_suppression_base' => '¡ATENCIÓN, la supresión de datos es irreversible!',

	// B
	'bouton_acces_ldap' => 'Añadir un acceso LDAP',
	'bouton_ajouter' => 'Añadir',
	'bouton_annuler' => 'Anular',
	'bouton_cache_activer' => 'Reactivar la caché',
	'bouton_cache_desactiver' => 'Desactivar temporalmente la caché',
	'bouton_demande_publication' => 'Pedir la publicación de este artículo',
	'bouton_desactive_tout' => 'Desactivar todo',
	'bouton_desinstaller' => 'Desinstalar',
	'bouton_effacer_tout' => '¡Borrar TODO!',
	'bouton_envoyer_message' => 'Mensaje definitivo: enviar',
	'bouton_fermer' => 'Cerrar',
	'bouton_mettre_a_jour' => 'Actualizar',
	'bouton_mettre_a_jour_base' => 'Actualizar la base de datos',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Mostrar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Aparecer en la lista de redactores y redactoras conectados', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Enviar los anuncios a la dirección:',
	'bouton_radio_envoi_liste_nouveautes' => 'Enviar la lista de novedades',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'No aparecer en la lista de redactores y redactoras', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'No enviar anuncios editoriales',
	'bouton_redirection' => 'Redirección',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Reinicializar a los valores por omisión',
	'bouton_relancer_inscription' => 'Relanzar la inscripción',
	'bouton_relancer_inscriptions' => 'Relanzamiento de las inscripciones',
	'bouton_relancer_installation' => 'Relanzar la instalación',
	'bouton_reset_password' => 'Generar una nueva contraseña y enviarla por correo electrónico',
	'bouton_suivant' => 'Siguiente',
	'bouton_tenter_recuperation' => 'Intentar reparar',
	'bouton_test_proxy' => 'Probar el proxy',
	'bouton_vider_cache' => 'Vaciar la caché',

	// C
	'cache_modifiable_webmestre' => 'Este parámetro es modificable por la webmistress del sitio.', # MODIF
	'calendrier_synchro' => 'Si utiliza un software de agenda compatible <b>iCal</b>, puede sincronizarlo con la actualidad editorial de este sitio.',
	'config_activer_champs' => 'Activar los campos siguientes',
	'config_choix_base_sup' => 'indicar una base de datos de este servidor',
	'config_erreur_base_sup' => 'SPIP no tiene acceso a la lista de bases accesibles',
	'config_info_base_sup' => 'Si dispone de otras bases de datos a consultar mediante SPIP, con su servidor SQL o con otro, el formulario siguiente permite declararlas. Si deja vacíos ciertos campos, se usarán los identificadores de la conexión a la base principal.',
	'config_info_base_sup_disponibles' => 'Bases de datos suplementarias consultables:',
	'config_info_enregistree' => 'La nueva configuración fue guardada',
	'config_info_logos' => 'Cada elemento del sitio puede tener un logo, así como un « logo de paso del ratón »',
	'config_info_logos_utiliser' => 'Utilizar los logos',
	'config_info_logos_utiliser_non' => 'No utilizar los logos',
	'config_info_logos_utiliser_survol' => 'Utilizar los logos de paso del ratón',
	'config_info_logos_utiliser_survol_non' => 'No utilizar los logos de paso del ratón',
	'config_info_redirection' => 'Activando esta opción, se podrán crear artículos virtuales, que son simples referencias de artículos publicados en otros sitios o fuera de SPIP.',
	'config_redirection' => 'Artículos virtuales',
	'config_titre_base_sup' => 'Declaración de una base suplementaria',
	'config_titre_base_sup_choix' => 'Elige una base suplementaria',
	'connexion_ldap' => 'Conexión:',
	'creer_et_associer_un_auteur' => 'Crear y asociar un autor',

	// D
	'date_mot_heures' => 'horas',

	// E
	'ecran_connexion_couleur_principale' => 'Color principal',
	'ecran_connexion_image_fond' => 'Imagen de fondo',
	'ecran_connexion_image_fond_explication' => 'Utilizar una imagen (en formato JPEG, 1920x1080 píxeles)',
	'ecran_connexion_image_revenir_couleur_defaut' => 'Volver al color por defecto',
	'ecran_connexion_titre' => 'Pantalla de acceso',
	'ecran_securite' => ' + pantalla de seguridad @version@',
	'email' => 'correo electrónico',
	'email_2' => 'correo electrónico:',
	'en_savoir_plus' => 'Más información',
	'entree_adresse_annuaire' => 'Dirección del anuario',
	'entree_adresse_email' => 'Tu correo electrónico',
	'entree_adresse_email_2' => 'Dirección correo electrónico',
	'entree_base_donnee_1' => 'Dirección de la base de datos',
	'entree_base_donnee_2' => '(A menudo esta dirección corresponde a la de su sitio, a veces corresponde a la mención «localhost» y, en ocasiones, se deja totalmente vacía.)',
	'entree_biographie' => 'Una corta biografía, en pocas palabras...',
	'entree_chemin_acces' => '<b>Introducir</b> el camino de acceso:',
	'entree_cle_pgp' => 'Su clave PGP',
	'entree_cle_pgp_2' => 'Clave PGP',
	'entree_contenu_rubrique' => '(Contenido de la sección en pocas palabras)',
	'entree_identifiants_connexion' => 'Sus identificadores de conexión...',
	'entree_identifiants_connexion_2' => 'Identificadores de conexión',
	'entree_informations_connexion_ldap' => 'Escriba en este formulario los datos de conexión a su directorio LDAP. Tales informaciones le serán transmitidas por el administrador del sistema o de la red.', # MODIF
	'entree_infos_perso' => '¿Quién es usted?',
	'entree_infos_perso_2' => '¿Quién es el/la autor/a?',
	'entree_interieur_rubrique' => 'En el interior de la sección...',
	'entree_liens_sites' => '<b>Enlace hipertexto </b>(referencia, sitio para visitar, ...)',
	'entree_login' => 'Su nombre de usuario',
	'entree_login_connexion_1' => 'Su identificador de conexión',
	'entree_login_connexion_2' => '(A veces corresponde a su identificador de conexión; a veces se deja vacío)',
	'entree_mot_passe' => 'Su contraseña',
	'entree_mot_passe_1' => 'Su contraseña de conexión',
	'entree_mot_passe_2' => '(A veces corresponde a tu contraseña FTP y a veces se deja en blanco)',
	'entree_nom_fichier' => 'Introducir el nombre del archivo @texte_compresse@:',
	'entree_nom_pseudo' => 'Su nombre o pseudónimo',
	'entree_nom_pseudo_1' => '(Su nombre o pseudónimo)',
	'entree_nom_pseudo_2' => 'Nombre o seudónimo',
	'entree_nom_site' => 'El nombre de su sitio',
	'entree_nom_site_2' => 'Nombre del sitio del/a autor/a',
	'entree_nouveau_passe' => 'Nueva contraseña',
	'entree_passe_ldap' => 'Tu contraseña',
	'entree_port_annuaire' => 'El número de puerto del anuario',
	'entree_signature' => 'Firma',
	'entree_titre_obligatoire' => '<b>Título</b> [Obligatorio]<br />',
	'entree_url' => 'La dirección (URL) de su sitio',
	'entree_url_2' => 'Dirección (URL) del sitio',
	'erreur_connect_deja_existant' => 'Ya existe un servidor con este nombre',
	'erreur_contenu_suspect' => 'Cotenido con algún error',
	'erreur_email_deja_existant' => 'Esta dirección de correo electrónico ya esta registrada.',
	'erreur_nom_connect_incorrect' => 'Este nombre de servidor no esta autorizado',
	'erreur_plugin_attribut_balise_manquant' => 'Atributo @attribut@ que falta en la   baliza @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'La desinstalación del plugin ha fracasado. No obstante, puede desactivarlo.',
	'erreur_plugin_fichier_absent' => 'Archivo inexistente ',
	'erreur_plugin_fichier_def_absent' => 'Archivo de definición inexistente',
	'erreur_plugin_nom_fonction_interdit' => 'Nombre de función prohibido',
	'erreur_plugin_nom_manquant' => 'Falta el nombre del plugin',
	'erreur_plugin_prefix_manquant' => 'Espacio de nombres del plugin no definido',
	'erreur_plugin_tag_plugin_absent' => 'Falta el &lt;plugin&gt; en el archivo de  definición',
	'erreur_plugin_version_manquant' => 'Falta la versión del plugin',
	'erreur_type_fichier' => 'Tipo de archivo incorrecto',

	// H
	'htaccess_a_simuler' => 'Advertencia: la configuración de su servidor HTTP no toma en cuenta los archivos @htaccess@. Para poder asegurar una buena seguridad, debe modificar la configuración correspondiente, o bien que las constantes @constantes@ (que se pueden definir en el archivo mes_options.php) tomen valores de carpetas fuera de @document_root@.',
	'htaccess_inoperant' => 'htaccess inoperante',

	// I
	'ical_info1' => 'En esta página se presentan diferentes maneras de quedar en contacto con la vida del sitio.',
	'ical_info2' => 'Para mayor información sobre todas estas técnicas, no dude en consultar <a href="@spipnet@">la documentación de SPIP</a>.',
	'ical_info_calendrier' => 'Tiene dos calendarios a tu disposición. El primero es un plano del sitio que anuncia todos los artículos publicados. El segundo contiene los anuncios editoriales y sus últimos mensajes privados: sólo usted lo ve gracias a una clave personal, que podrá modificar en cualquier momento cambiando su contraseña.',
	'ical_methode_http' => 'Descargar',
	'ical_methode_webcal' => 'Sincronización (webcal://)',
	'ical_texte_prive' => 'Este calendario, de uso estrictamente personal, le informa de la actividad editorial privada de este sitio (tareas y citas personales, artículos y breves propuestos...).',
	'ical_texte_public' => 'Este calendario permite seguir la actividad pública del sitio (artículos y breves publicados).',
	'ical_texte_rss' => 'Puede sindicar las novedades de este sitio con cualquier lector de archivos al formato XML/RSS (Rich Site Summary). Igualmente, SPIP puede leer las novedades publicadas en otros sitios que utilizan un formato de intercambio compatible (sitios sindicados). ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de correo',
	'ical_titre_rss' => 'Archivos de sindicación',
	'icone_accueil' => 'Mis tareas',
	'icone_activer_cookie' => 'Activar la "cookie" de correspondencia',
	'icone_activite' => 'Actividad',
	'icone_admin_plugin' => 'Gestión de los plugins',
	'icone_administration' => 'Administración',
	'icone_afficher_auteurs' => 'Mostrar los autores',
	'icone_afficher_visiteurs' => 'Mostrar los visitantes',
	'icone_arret_discussion' => 'No participar más en este diálogo',
	'icone_calendrier' => 'Calendario',
	'icone_configuration' => 'Configuración',
	'icone_creer_auteur' => 'Crear un nuevo autor o autora y asociarla a este artículo',
	'icone_creer_mot_cle' => 'Crear una nueva palabra clave y asociarla a este artículo',
	'icone_creer_rubrique_2' => 'Crear una nueva sección',
	'icone_developpement' => 'Desarrollo',
	'icone_edition' => 'Edición',
	'icone_ma_langue' => 'Mi idioma',
	'icone_mes_infos' => 'Mis datos',
	'icone_mes_preferences' => 'Mis preferencias',
	'icone_modifier_article' => 'Modificar este artículo',
	'icone_modifier_rubrique' => 'Modificar esta sección',
	'icone_publication' => 'Publicación',
	'icone_relancer_signataire' => 'Recordar al firmante',
	'icone_retour' => 'Volver',
	'icone_retour_article' => 'Volver al artículo',
	'icone_squelette' => 'Esqueletos',
	'icone_suivi_publication' => 'Seguir la publicación',
	'icone_supprimer_cookie' => 'Suprimir la "cookie" de correspondencia',
	'icone_supprimer_rubrique' => 'Suprimir esta sección',
	'icone_supprimer_signature' => 'Suprimir esta firma',
	'icone_valider_signature' => 'Validar esta firma',
	'image_administrer_rubrique' => 'Puedes administrar esta sección',
	'impossible_modifier_login_auteur' => 'Imposible modificar el nombre de usuario.',
	'impossible_modifier_pass_auteur' => 'Imposible modificar la contraseña.',
	'info_1_article' => '1 artículo',
	'info_1_auteur' => '1 autor/a',
	'info_1_message' => '1 mensaje',
	'info_1_mot_cle' => '1 palabra-clave',
	'info_1_rubrique' => '1 sección',
	'info_1_visiteur' => '1 visitante',
	'info_activer_cookie' => 'Puede activar una <b>"cookie" de correspondencia</b>, que le permite actualizar páginas y pasar fácilmente de la parte pública a la redacción.',
	'info_activer_menu_developpement' => 'Mostrar el menu desarrollo ',
	'info_admin_etre_webmestre' => 'Darme derechos de webmaster',
	'info_admin_je_suis_webmestre' => 'Soy <b>webmaster</b>',
	'info_admin_statuer_webmestre' => 'Dar a este/a administrador/a derechos de webmaster', # MODIF
	'info_admin_webmestre' => 'Este/a administrador/a es <b>webmaster</b>', # MODIF
	'info_administrateur' => 'Administrador', # MODIF
	'info_administrateur_1' => 'Administrador', # MODIF
	'info_administrateur_2' => 'del sitio (<i>a utilizar con precaución</i>)',
	'info_administrateur_site_01' => 'Si tiene derechos de administración, se ruega', # MODIF
	'info_administrateur_site_02' => 'presiona y visita este enlace',
	'info_administrateurs' => 'Administradores', # MODIF
	'info_administrer_rubrique' => 'Puede administrar esta sección',
	'info_adresse' => 'a la dirección:',
	'info_adresse_desinscription' => 'Dirección para darse de baja:',
	'info_adresse_url' => 'Dirección (URL) del sitio público',
	'info_afficher_par_nb' => 'Visualizar por',
	'info_aide_en_ligne' => 'Ayuda en línea de SPIP',
	'info_ajout_image' => 'Cuando se añaden imágenes en tanto que documentos, SPIP puede crear automáticamente iconos de estas imágenes insertadas (miniaturas). Resulta útil, por ejemplo, para crear una galería o portafolio.',
	'info_ajouter_rubrique' => 'Añadir otra sección para administrar:',
	'info_annonce_nouveautes' => 'Anunciar novedades',
	'info_article' => 'artículo',
	'info_article_2' => 'artículos',
	'info_article_a_paraitre' => 'Los artículos con fecha posterior a ser publicados',
	'info_articles_02' => 'artículos',
	'info_articles_2' => 'Artículos',
	'info_articles_auteur' => 'Los artículos de este autor o autora',
	'info_articles_miens' => 'Mis artículos',
	'info_articles_tous' => 'Todos los artículos',
	'info_articles_trouves' => 'Artículos localizados',
	'info_attente_validation' => 'Sus artículos en espera de validación',
	'info_aucun_article' => 'Ningún artículo',
	'info_aucun_auteur' => 'Ningún autor',
	'info_aucun_message' => 'Ningún mensaje',
	'info_aucun_rubrique' => 'Ninguna sección',
	'info_aujourdhui' => 'hoy:',
	'info_auteur_gere_rubriques' => 'Este autor gestiona las secciones siguientes :',
	'info_auteur_gere_toutes_rubriques' => 'este autor gestiona <b>todas las secciones</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'yo gestiono <b>todas las secciones</b>',
	'info_auteurs' => 'Autores',
	'info_auteurs_par_tri' => 'Autores@partri@',
	'info_auteurs_trouves' => 'Autores encontrados',
	'info_authentification_externe' => 'Autentificación externa',
	'info_avertissement' => 'Advertencia',
	'info_barre_outils' => '¿con su barra de herramientas?',
	'info_base_installee' => 'La estructura de tu base de datos ha sido instalada',
	'info_bio' => 'Biografía',
	'info_cache_desactive' => 'La caché está temporalmente desactivada.',
	'info_chapeau' => 'Epígrafe',
	'info_chapeau_2' => 'Epígrafe:',
	'info_chemin_acces_1' => 'Opciones: <b>Camino de acceso en el directorio</b>',
	'info_chemin_acces_2' => 'Debe configurar el camino de acceso a la información en el anuario. Esta información es indispensable para leer los perfiles de personas almacenadas en el anuario.', # MODIF
	'info_chemin_acces_annuaire' => 'Opciones: <b>Camino de acceso en el directorio</b>',
	'info_choix_base' => 'Tercera etapa:',
	'info_classement_1' => '<sup>o</sup> sobre @liste@',
	'info_classement_2' => '<sup>o</sup> sobre @liste@',
	'info_code_acces' => '¡No olvide sus códigos de acceso!',
	'info_config_suivi' => 'Si esta dirección corresponde a una lista de correo, puede indicar aquí abajo la dirección en la cual los participantes del sitio pueden inscribirse. Esta dirección puede ser una URL (por ejemplo la página de inscripción a la lista por la web), o una dirección de correo electrónico con un asunto específico (por ejemplo: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Puede suscribirse a la lista de correo de este sitio. Recibirás por correo electrónico los anuncios de artículos y de breves propuestas a la publicación.',
	'info_confirmer_passe' => 'Confirmar la nueva contraseña:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Atención, los siguientes campos han sido modificados por otro lado. Sus modificaciones sobre estos campos no han sido por tanto registradas.',
	'info_conflit_edition_differences' => 'Diferencias:',
	'info_conflit_edition_version_enregistree' => 'La versión registrada:',
	'info_conflit_edition_votre_version' => 'Su versión:',
	'info_connexion_base' => 'Intento de conexión a la base',
	'info_connexion_base_donnee' => 'Conexión a su base de datos',
	'info_connexion_ldap_ok' => '<b>Se logró la conexión LDAP.</b><p> Puede pasar a la etapa siguiente.</p>',
	'info_connexion_mysql' => 'Tu conexión SQL',
	'info_connexion_ok' => 'La conexión ha funcionado.',
	'info_contact' => 'Contacto',
	'info_contenu_articles' => 'Contenido de los artículos',
	'info_contributions' => 'Contribuciones',
	'info_creation_paragraphe' => 'Para crear párrafos, deje simplemente líneas vacías.',
	'info_creation_rubrique' => 'Antes de poder escribir artículos,<br /> debe crear al menos una sección.<br />',
	'info_creation_tables' => 'Creación de las tablas de la base',
	'info_creer_base' => '<b>Crear</b> una nueva base de datos:',
	'info_dans_rubrique' => 'En la sección...',
	'info_date_publication_anterieure' => 'Fecha de redacción anterior:',
	'info_date_referencement' => 'FECHA DE SINDICACIÓN DE ESTE SITIO :',
	'info_derniere_etape' => '¡Ya terminamos!',
	'info_descriptif' => 'Descripción:',
	'info_desinstaller_plugin' => 'suprime los datos y desactiva el plugin',
	'info_discussion_cours' => 'Debates en curso',
	'info_ecrire_article' => 'Antes de escribir artículos, debe crear una sección.',
	'info_email_envoi' => 'Dirección de correo de envío (opcional)',
	'info_email_envoi_txt' => 'Indique aqui la dirección a utilizar para enviar los correos electrónicos (por defecto, se utiliza la dirección del destinatario como dirección de envío):',
	'info_email_webmestre' => 'Dirección de correo electrónico del webmaster', # MODIF
	'info_envoi_email_automatique' => 'Envío automático de correos electrónicos',
	'info_envoyer_maintenant' => 'Enviar ahora',
	'info_etape_suivante' => 'Pasar a la siguiente etapa ',
	'info_etape_suivante_1' => 'Puede pasar a la siguiente etapa ',
	'info_etape_suivante_2' => 'Puede pasar a la siguiente etapa',
	'info_exceptions_proxy' => 'Excepciones para el proxy',
	'info_exportation_base' => 'exportación de la base hacia @archive@',
	'info_facilite_suivi_activite' => 'Para facilitar el seguimiento de la actividad editorial, SPIP puede enviar por correo electrónico, por ejemplo a un lista de redactores, anuncios de solicitudes de publicación y de validación de artículos. Indique una o más direcciones, separadas por comas.', # MODIF
	'info_fichiers_authent' => 'Archivos de autentificación «.htpasswd»',
	'info_forums_abo_invites' => 'Su sitio tiene foros para abonados; en el sitio público se invita a los visitantes a que se registren.', # MODIF
	'info_gauche_admin_tech' => '<b>Esta página sólo es accesible para los responsables del sitio.</b><p> Da acceso a las distintas funciones de mantenimiento técnico. Algunas de ellas requieren un proceso de autentificación para el cual es necesario tener acceso por FTP al sitio web.</p>',
	'info_gauche_auteurs' => 'Aquí figuran todos los autores del sitio.
 Su estatus se indica mediante el color de su icono (administrador/a = verde; redactor/a = amarillo).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Los autores exteriores, sin acceso al sitio, están indicados con un icono azul; los que están borrados por un icono gris.',
	'info_gauche_messagerie' => 'La mensajería permite comunicarse, crear recordatorios para traer a la memoria algo o publicar anuncios (en el caso de pertenecer al grupo de administración).', # MODIF
	'info_gauche_statistiques_referers' => 'Esta página presenta la lista de los <i>referers</i>, es decir, de los sitios que contienen enlaces que llevan a su propio sitio, sólo para ayer y hoy; esta lista se pone a cero cada 24 horas.',
	'info_gauche_visiteurs_enregistres' => 'Aquí se encuentran las personas registradas en el espacio público del sitio (foros con suscripción).',
	'info_generation_miniatures_images' => 'Generación de las miniaturas de imágenes',
	'info_gerer_trad_objets' => '@objets@: manejar los vínculos de traducción',
	'info_hebergeur_desactiver_envoi_email' => 'Algunos servidores no permiten el envío automático de correos electrónicos. En esos casos, las siguientes funciones de SPIP no darán ningún resultado.',
	'info_hier' => 'ayer:',
	'info_identification_publique' => 'Su identidad pública...',
	'info_image_process' => 'Por favor seleccione el mejor método de fabricación de viñetas pinchando en la imágen correspondiente. ',
	'info_image_process2' => 'Si no aparece ninguna imagen, es que el servidor que alberga su sitio web no está configurado para usar estas herramientas. Si quiere utilizarlas, contacte al responsable técnico y solicite las extensiones «GD» o «Imagick».',
	'info_images_auto' => 'Imágenes calculadas automáticamente',
	'info_informations_personnelles' => 'Información personal',
	'info_inscription' => 'Inscripción el',
	'info_inscription_automatique' => 'Inscripcción automática de nuevos redactores', # MODIF
	'info_jeu_caractere' => 'Juego de caracteres del sitio',
	'info_jours' => 'días',
	'info_laisser_champs_vides' => 'dejar estos campos vacíos)',
	'info_langues' => 'Idiomas del sitio',
	'info_ldap_ok' => 'La autentificación LDAP está instalada.',
	'info_lien_hypertexte' => 'Enlace hipertexto:',
	'info_liste_nouveautes_envoyee' => 'La lista de novedades ha sido enviada',
	'info_liste_redacteurs_connectes' => 'Lista de redactores conectados', # MODIF
	'info_login_existant' => 'Este nombre de usuario ya existe.',
	'info_login_trop_court' => 'Identificador de usuario muy corto.',
	'info_login_trop_court_car_pluriel' => 'El identificador de usuario debe contener por lo menos @nb@ caracteres.',
	'info_logos' => 'Los logos',
	'info_maximum' => 'máximo:',
	'info_meme_rubrique' => 'En la misma sección',
	'info_message_en_redaction' => 'Sus mensajes en curso de redacción',
	'info_message_technique' => 'Mensaje técnico:',
	'info_messagerie_interne' => 'Mensajería interna',
	'info_mise_a_niveau_base' => 'actualización de su base SQL',
	'info_mise_a_niveau_base_2' => '{{¡ATENCIÓN!}} Ha instalado una versión de los archivos SPIP {anterior} a la que se encontraba antes en este sitio:  corre el riesgo de perder la base de datos y que el sitio deje de funcionar.<br />{{Vuelva a instalar los archivos de SPIP.}}',
	'info_modification_enregistree' => 'Su modificación fue grabada',
	'info_modifier_auteur' => 'Modificar el autor:',
	'info_modifier_rubrique' => 'Modificar la sección',
	'info_modifier_titre' => 'Modificar @titre@',
	'info_mon_site_spip' => 'Mi sitio SPIP',
	'info_moyenne' => 'promedio:',
	'info_multi_cet_article' => 'Idioma de este artículo:',
	'info_multi_langues_choisies' => 'A continuación seleccione los idiomas que quiera poner a disposición de los redactores de su sitio.
Los idiomas que ya se utilizan en el sitio (al principio de la lista) no pueden ser desactivados.
', # MODIF
	'info_multi_objets' => '@objets@: activar el menú de idioma',
	'info_multi_secteurs' => '... sólo para las secciones situadas en la raíz?',
	'info_nb_articles' => '@nb@ artículos',
	'info_nb_auteurs' => '@nb@ autores',
	'info_nb_messages' => '@nb@ mensajes',
	'info_nb_mots_cles' => '@nb@ palabras-claves',
	'info_nb_rubriques' => '@nb@ secciones',
	'info_nb_visiteurs' => '@nb@ visitantes',
	'info_nom' => 'Nombre',
	'info_nom_destinataire' => 'Nombre del destinatario o destinataria',
	'info_nom_pas_conforme' => 'las etiquetas HTML no están permitidas',
	'info_nom_site' => 'Nombre de tu sitio',
	'info_nombre_articles' => '@nb_articles@ artículos,',
	'info_nombre_rubriques' => '@nb_rubriques@ secciones,',
	'info_nombre_sites' => '@nb_sites@ sitios,',
	'info_non_deplacer' => 'No desplazar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP puede enviar regularmente la lista de las novedades del sitio (artículos y breves).',
	'info_non_envoi_liste_nouveautes' => 'No enviar la lista de novedades',
	'info_non_modifiable' => 'no puede ser modificado',
	'info_non_suppression_mot_cle' => 'No deseo suprimir esta palabra clave',
	'info_notes' => 'Notas',
	'info_nouvel_article' => 'Nuevo artículo',
	'info_nouvelle_traduction' => 'Nueva traducción:',
	'info_numero_article' => 'ARTÍCULO NÚMERO:',
	'info_obligatoire_02' => '(obligatorio)',
	'info_option_accepter_visiteurs' => 'Aceptar la inscripción de los visitantes del sitio público', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Rechazar la inscripción de visitantes', # MODIF
	'info_options_avancees' => 'OPCIONES AVANZADAS',
	'info_ou' => 'o...',
	'info_page_interdite' => 'Página no accesible',
	'info_par_nom' => 'por nombre',
	'info_par_nombre_article' => 'por número de artículos',
	'info_par_statut' => 'por estatus',
	'info_par_tri' => '’(por @tri@)’',
	'info_passe_trop_court' => 'Contraseña demasiado corta',
	'info_passe_trop_court_car_pluriel' => 'La contraseña debe contener al menos @nb@ caracteres.',
	'info_passes_identiques' => 'Hay diferencias entre las dos contraseñas',
	'info_plus_cinq_car' => 'más de 5 caracteres',
	'info_plus_cinq_car_2' => '(Más de 5 caracteres)',
	'info_plus_trois_car' => '(Más de tres caracteres)',
	'info_popularite' => 'Popularidad: @popularite@ Visitas: @visites@',
	'info_post_scriptum' => 'Post Scríptum',
	'info_post_scriptum_2' => 'Post Scríptum:',
	'info_pour' => 'para',
	'info_preview_texte' => 'Es posible previsualizar los diferentes elementos editoriales del sitio que tengan por lo menos el estatuto de "propuesto", así como los elementos que están en curso de redacción y de los que seamos el autor. Esta función debe estar disponible para los administradores, los redactores, o para nadie ?

', # MODIF
	'info_procedez_par_etape' => 'proceda etapa por etapa',
	'info_procedure_maj_version' => 'Se debe ejecutar el proceso de actualización de la base de datos a esta nueva versión de SPIP.',
	'info_proxy_ok' => 'Test del proxy logrado.',
	'info_ps' => 'P.-S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Sus artículos publicados',
	'info_question_accepter_visiteurs' => 'Si en los esqueletos de su sitio está previsto el registro de visitantes sin acceso al espacio privado, tendrá que activar la opción siguiente:', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => '¿Se aceptan inscripciones de nuevas redactoras y redactores
  desde el sitio público? Si se aceptan, las personas que visitan el sitio
  podrán inscribirse desde un formulario automatizado y accederán entonces
  al espacio privado para proponer sus propios artículos. <div class="notice">Durante
  la fase de inscripción, reciben un correo electrónico automático que les indica sus
  códigos de acceso al sitio privado. Ciertos proveedores de hospedaje desactivan 
  el envío de correos electrónicos desde sus servidores: en tal caso, se hace
  imposible la inscripción automática.</div>', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ ha trabajado en este contenido hace @date_diff@ minutos',
	'info_racine_site' => 'Raíz del sitio',
	'info_recharger_page' => 'Por favor recargue esta página dentro de un momento',
	'info_recherche_auteur_zero' => 'No hay resultados para « @cherche_auteur@ ».',
	'info_recommencer' => 'Vuelva a empezar.',
	'info_redacteur_1' => 'Redactor/a',
	'info_redacteur_2' => 'teniendo acceso al espacio privado (<i>recomendado</i>)',
	'info_redacteurs' => 'Redactores/as',
	'info_redaction_en_cours' => 'EN CURSO DE REDACCIÓN',
	'info_redirection' => 'Redirección',
	'info_redirection_activee' => 'La redirección está activada.',
	'info_redirection_boucle' => 'Usted esta probando redirigir el artículo hacía el mismo.',
	'info_redirection_desactivee' => 'La redirección se ha suprimido.',
	'info_refuses' => 'Sus artículos rechazados',
	'info_reglage_ldap' => 'Opciones: <b>Ajustes de la importación LDAP</b>',
	'info_renvoi_article' => '<b>Redirección.</b> Este artículo reenvía a la página:',
	'info_reserve_admin' => 'Sólo el equipo de administración puede modificar esta dirección', # MODIF
	'info_restreindre_rubrique' => 'Limitar la gestión a la sección:',
	'info_resultat_recherche' => 'Resultados de la búsqueda:',
	'info_rubriques' => 'Secciones',
	'info_rubriques_02' => 'secciones',
	'info_rubriques_trouvees' => 'Secciones localizadas',
	'info_sans_titre' => 'Sin título',
	'info_selection_chemin_acces' => 'Seleccione el camino de acceso en el anuario',
	'info_signatures' => 'firmas',
	'info_site' => 'Sitio',
	'info_site_2' => 'sitio:',
	'info_site_min' => 'sitio',
	'info_site_reference_2' => 'Sitio referenciado',
	'info_site_web' => 'Sitio Web:',
	'info_sites' => 'sitios',
	'info_sites_lies_mot' => 'Los sitios referenciados ligados a esta palabra clave',
	'info_sites_proxy' => 'Utilizar un proxy',
	'info_sites_trouves' => 'Sitios hallados',
	'info_sous_titre' => 'Subtítulo',
	'info_statut' => 'Estatuto',
	'info_statut_administrateur' => 'Administrador/a', # MODIF
	'info_statut_auteur' => 'Estatus de este autor o autora:',
	'info_statut_auteur_2' => 'Soy',
	'info_statut_auteur_a_confirmer' => 'Inscripción por confirmar',
	'info_statut_auteur_autre' => 'Otro papel:',
	'info_statut_redacteur' => 'Redactor/a',
	'info_statut_utilisateurs_1' => 'Estatus por defecto de usuarios importados', # MODIF
	'info_statut_utilisateurs_2' => 'Elija el estatus atribuido a las personas presentes en el directorio LDAP cuando se conectan por primera vez. Posteriormente podrá modificar este valor para cada autor en cada caso.', # MODIF
	'info_suivi_activite' => 'Seguimiento de la actividad editorial',
	'info_surtitre' => 'Antetítulo:',
	'info_syndication_integrale_1' => 'Su sitio propone archivos de sindicación (ver «<a href="@url@">@titre@</a>»).',
	'info_syndication_integrale_2' => '¿Desea transmitir íntegramente los artículos, o sólo un resumen compuesto por unos cientos de caracteres?',
	'info_table_prefix' => 'Puede modificar el prefijo del nombre de las tablas de datos (es indispensable si se quiere instalar varios sitios en la misma base de datos). Este prefijo debe ser en letras minúsculas, no acentuadas, y sin espacios. ',
	'info_taille_maximale_images' => 'SPIP comprobará el tamaño máximo de imagen que puede gestionar (en millones de pixels).<br /> Las imágenes mayores no se reducirán.',
	'info_taille_maximale_vignette' => 'Tamaño máximo de los iconos generados por el sistema:',
	'info_terminer_installation' => 'Puede terminar ahora el procedimiento de instalación estándar.',
	'info_texte' => 'Texto',
	'info_texte_explicatif' => 'Texto explicativo',
	'info_texte_long' => '(el texto es largo: aparece en varias partes que serán reunidas tras validación)',
	'info_texte_message' => 'Texto de su mensaje',
	'info_texte_message_02' => 'Texto del mensaje',
	'info_titre' => 'Título:',
	'info_total' => 'total:',
	'info_tous_articles_en_redaction' => 'Todos los artículos en curso de redacción',
	'info_tous_articles_presents' => 'Todos los artículos publicados en esta sección',
	'info_tous_articles_refuses' => 'Todos los artículos rechazados',
	'info_tous_les' => 'todos los:',
	'info_tout_site' => 'Todo el sitio',
	'info_tout_site2' => 'El artículo no ha sido traducido a este idioma.',
	'info_tout_site3' => 'El artículo ha sido traducido a este idioma, pero posteriormente se han aportado modificaciones al artículo de referencia. La traducción debe ser actualizada.',
	'info_tout_site4' => 'El artículo ha sido traducido a este idioma, y la traducción está al día. ',
	'info_tout_site5' => 'Artículo original',
	'info_tout_site6' => '<b>Atención:</b> sólo se muestran los artículos originales.
Las traducciones están asociadas al original, en un color que indica su estado:',
	'info_traductions' => 'Traducciones',
	'info_travail_colaboratif' => 'Trabajo colectivo en los artículos',
	'info_un_article' => 'un artículo,',
	'info_un_site' => 'un sitio,',
	'info_une_rubrique' => 'una sección,',
	'info_une_rubrique_02' => '1 sección',
	'info_url' => 'URL:',
	'info_url_proxy' => 'URL del proxy',
	'info_url_proxy_pas_conforme' => 'La URL del proxy no es válido.',
	'info_url_site_pas_conforme' => 'la URL del sitio no es válida.',
	'info_url_test_proxy' => 'URL de prueba',
	'info_urlref' => 'Enlace hipertexto:',
	'info_utilisation_spip' => 'Puede comenzar a utilizar el sistema de publicación asistida...',
	'info_visites_par_mois' => 'Mostrar por mes:',
	'info_visiteur_1' => 'Visitante',
	'info_visiteur_2' => 'del sitio público',
	'info_visiteurs' => 'Visitantes',
	'info_visiteurs_02' => 'Visitantes del sitio público',
	'info_webmestre_forces' => 'La lista de webmasters está actualmente definida en <tt>@file_options@</tt>.', # MODIF
	'install_adresse_base_hebergeur' => 'Dirección de la base de datos asignada por el proveedor del alojamiento',
	'install_connect_ok' => 'La nueva base de datos fue declarada con éxito con el nombre de servidor @connect@.',
	'install_echec_annonce' => 'La instalación probablemente va a fallar, o creará un sitio que no funcione...',
	'install_extension_mbstring' => 'SPIP no funciona con:',
	'install_extension_php_obligatoire' => 'SPIP exige instalar la extensión php:',
	'install_login_base_hebergeur' => 'Nombre de usuario de conexión asignado por el proveedor del alojamiento',
	'install_nom_base_hebergeur' => 'Nombre de la base asignada por el proveedor:',
	'install_pas_table' => 'La base no tiene tablas en este momento',
	'install_pass_base_hebergeur' => 'Contraseña de conexión asignada por el proveedor',
	'install_php_extension' => 'Faltan las siguientes extensiones: @extensions@',
	'install_php_version' => 'PHP versión @version@ insuficiente (mínimo = @minimum@)',
	'install_php_version_max' => 'Versión PHP @version@ demasiado reciente (máximo = @maximum@)',
	'install_select_langue' => 'Seleccione un idioma y después pulse el botón «siguiente» para iniciar el proceso de instalación.',
	'install_select_type_db' => 'Indicar el tipo de base de datos:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servidor de base de datos asignado por tu proveedor',
	'install_table_prefix_hebergeur' => 'Prefijo de la tabla asignada por el proveedor:',
	'install_tables_base' => 'Tablas de la base',
	'install_types_db_connus' => 'SPIP sabe utilizar <b>MySQL</b> (el formato más extendido) y <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'También se propone el soporte para <b>PostgreSQL</b> en modo experimental.',
	'instituer_erreur_statut_a_change' => 'El estatus ya ha sido modificado',
	'instituer_erreur_statut_non_autorise' => 'No puede elegir este estatus',
	'intem_redacteur' => 'redactor/a',
	'intitule_licence' => 'Licencia',
	'item_accepter_inscriptions' => 'Aceptar las inscripciones',
	'item_activer_messages_avertissement' => 'Activar los mensajes de advertencia',
	'item_administrateur_2' => 'administrador/a', # MODIF
	'item_afficher_calendrier' => 'Mostrar en el calendario',
	'item_autoriser_syndication_integrale' => 'Difundir íntegramente los artículos en los archivos de sindicación',
	'item_choix_administrateurs' => 'los administradores', # MODIF
	'item_choix_generation_miniature' => 'Generar automáticamente las miniaturas de las imágenes',
	'item_choix_non_generation_miniature' => 'No generar miniaturas de las imágenes',
	'item_choix_redacteurs' => 'los redactores',
	'item_choix_visiteurs' => 'los visitantes del sitio público',
	'item_creer_fichiers_authent' => 'Crear los archivos «.htpasswd»',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Activar la mensajería y la agenda',
	'item_mots_cles_association_articles' => 'a los artículos',
	'item_mots_cles_association_rubriques' => 'a las secciones',
	'item_mots_cles_association_sites' => 'a los sitios referenciados o sindicados',
	'item_non' => 'No',
	'item_non_accepter_inscriptions' => 'No aceptar inscripciones',
	'item_non_activer_messages_avertissement' => 'Sin mensajes de advertencia',
	'item_non_afficher_calendrier' => 'No mostrar en el calendario',
	'item_non_autoriser_syndication_integrale' => 'Sólo difundir un resumen',
	'item_non_creer_fichiers_authent' => 'No crear esos archivos',
	'item_non_messagerie_agenda' => 'Desactivar la mensajería y la agenda',
	'item_non_publier_articles' => 'No publicar los artículos antes de la fecha de publicación indicada',
	'item_nouvel_auteur' => 'Nueva autora o autor',
	'item_nouvelle_rubrique' => 'Nueva sección',
	'item_oui' => 'Sí',
	'item_publier_articles' => 'Publicar los artículos sin tener en cuenta la fecha de publicación',
	'item_reponse_article' => 'Respuesta al artículo',
	'item_visiteur' => 'visitante',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_bando_outils' => 'Barra de herramientas',
	'label_bando_outils_afficher' => 'Mostrar herramientas',
	'label_bando_outils_masquer' => 'Ocultar herramientas',
	'label_choix_langue' => 'Seleccione su idioma',
	'label_langue' => 'Idioma',
	'label_nom_fichier_connect' => 'Indica el nombre utilizado para este servidor',
	'label_slogan_site' => 'Eslogan del sitio',
	'label_taille_ecran' => 'Ancho de pantalla',
	'label_texte_et_icones_navigation' => 'Menú de navegación',
	'label_texte_et_icones_page' => 'Aparencia en la página',
	'ldap_correspondance' => 'herencia del campo @champ@',
	'ldap_correspondance_1' => 'Herencia de los campos LDAP',
	'ldap_correspondance_2' => 'Por cada uno de los campos SPIP siguientes, indicar el nombre del campo LDAP correspondiente. Dejar vacío para no indicar ninguno, y separar con espacios o comas para que se prueben varios campos LDAP.',
	'lien_ajouter_auteur' => 'Añadir este autor',
	'lien_ajouter_une_rubrique' => 'Añadir esta sección',
	'lien_email' => 'correo electrónico',
	'lien_nom_site' => 'NOMBRE DEL SITIO:',
	'lien_rapide_contenu' => 'saltar al contenido',
	'lien_rapide_navigation' => 'Saltar a la navegación',
	'lien_rapide_recherche' => 'Saltar al buscador',
	'lien_retirer_auteur' => 'Retirar el autor',
	'lien_retirer_rubrique' => 'Retirar la sección',
	'lien_retirer_tous_auteurs' => 'Quitar todos los autores',
	'lien_retirer_toutes_rubriques' => 'Retirar todas las secciones',
	'lien_site' => 'sitio',
	'lien_tout_decocher' => 'desmarcar todo',
	'lien_tout_deplier' => 'Desplegar todo',
	'lien_tout_replier' => 'Replegar todo',
	'lien_tout_supprimer' => 'Suprimir todo',
	'lien_trier_nom' => 'Ordenar por nombre',
	'lien_trier_nombre_articles' => 'Ordenar por número de artículos',
	'lien_trier_statut' => 'Ordenar por estatus',
	'lien_voir_en_ligne' => 'VER LA LÍNEA:',
	'logo_article' => 'Logotipo del artículo',
	'logo_auteur' => 'Logotipo del autor',
	'logo_rubrique' => 'Logotipo de la sección',
	'logo_site' => 'Logotipo del sitio',
	'logo_standard_rubrique' => 'Logotipo estándar de las secciones',
	'logo_survol' => 'Logotipo paso del ratón',

	// M
	'menu_aide_installation_choix_base' => 'Elección de su base',
	'module_fichier_langue' => 'Archivo de idioma',
	'module_raccourci' => 'Acceso directo',
	'module_texte_affiche' => 'Texto mostrado',
	'module_texte_explicatif' => 'Puede insertar los siguientes accesos directos en los esqueletos de su sitio público. Serán traducidos automáticamente en los diferentes idiomas para los que existe un archivo de idioma.',
	'module_texte_traduction' => 'El archivo de idioma « @module@ » está disponible en:',
	'mois_non_connu' => 'desconocido',

	// N
	'nouvelle_version_spip' => 'La versión @version@ de SPIP está disponible',
	'nouvelle_version_spip_majeure' => 'Una nueva  versión SPIP @version@ está disponible',

	// O
	'onglet_contenu' => 'Contenido',
	'onglet_declarer_une_autre_base' => 'Declarar otra base',
	'onglet_discuter' => 'Discutir',
	'onglet_interactivite' => 'Interactividad',
	'onglet_proprietes' => 'Propriedades',
	'onglet_repartition_actuelle' => 'actualmente',
	'onglet_sous_rubriques' => 'Subsecciones',

	// P
	'page_pas_proxy' => 'Esta página no debe pasar por el proxy',
	'pas_de_proxy_pour' => 'Si fuera el caso, indica los servidores o  dominios para los cuales este proxy no debe aplicarse. (por ejemplo: @exemple@)',
	'phpinfo' => 'Configuración PHP',
	'plugin_charge_paquet' => 'Carga del paquete @name@',
	'plugin_charger' => 'Descargar',
	'plugin_erreur_charger' => 'error: no es posible cargar @zip@',
	'plugin_erreur_droit1' => 'La carpeta <code>@dest@</code> no es accesible en modo escritura.',
	'plugin_erreur_droit2' => 'Tendrás que verificar los derechos en esta carpeta (o crearla si es el caso), o instalar los archivos por FTP.',
	'plugin_erreur_zip' => 'fallo de pclzip: error @status@',
	'plugin_etat_developpement' => 'en desarrollo',
	'plugin_etat_experimental' => 'experimental',
	'plugin_etat_stable' => 'estable',
	'plugin_etat_test' => 'en prueba',
	'plugin_impossible_activer' => 'Imposible activar el plugin @plugin@',
	'plugin_info_automatique1' => 'Si quiere autorizar la instalación automática de los plugins, ha de:',
	'plugin_info_automatique1_lib' => 'Si desea autorizar la instalación automática de esta librería, consulte:',
	'plugin_info_automatique2' => 'crear una carpeta <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'verificar que el servidor tiene permiso para escribir en esa carpeta.',
	'plugin_info_automatique_creer' => 'que hay que crear en la raíz del sitio.',
	'plugin_info_automatique_exemples' => 'ejemplos:',
	'plugin_info_automatique_ftp' => 'Puede instalar plugins, por FTP, en la carpeta <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Ciertos plugins también requieren que se pueda descargar archivos a la carpeta <code>lib/</code>, que habrá que crear, si es el caso, en la raíz del sitio.',
	'plugin_info_automatique_liste' => 'Sus listas de plugins:',
	'plugin_info_automatique_liste_officielle' => 'los plugins oficiales',
	'plugin_info_automatique_liste_update' => 'Actualizar las listas',
	'plugin_info_automatique_ou' => 'o...',
	'plugin_info_automatique_select' => 'Seleccione un plugin de aquí: SPIP lo descargará y lo instalará en la carpeta <code>@rep@</code>; si el plugin ya existe, se actualizará.',
	'plugin_info_credit' => 'Créditos',
	'plugin_info_erreur_xml' => 'La declaración de este plugin es incorrecta',
	'plugin_info_install_ok' => 'Instalación exitosa',
	'plugin_info_necessite' => 'Necesita:',
	'plugin_info_non_compatible_spip' => 'Este plugin no es compatible con esta versión de SPIP',
	'plugin_info_plugins_dist_1' => 'Las plugins siguientes se cargan y se activan en la carpeta @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'No pueden desactivarse.',
	'plugin_info_telecharger' => 'se descargará de @url@ y se instalará en @rep@',
	'plugin_info_upgrade_ok' => 'Actualización exitosa',
	'plugin_librairies_installees' => 'Bibliotecas instaladas',
	'plugin_necessite_extension_php' => 'Necesita la extensión PHP @plugin@ en versión @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Necesita la extensión PHP @plugin@',
	'plugin_necessite_lib' => 'Este plugin necesita la biblioteca @lib@',
	'plugin_necessite_php' => 'Necesita @plugin@ en versión @version@.',
	'plugin_necessite_plugin' => 'Necesita el plugin @plugin@ con versión @version@ por lo menos.',
	'plugin_necessite_plugin_sans_version' => 'Necesita el plugin @plugin@',
	'plugin_necessite_spip' => 'Necesita como mínimo un SPIP de versión @version@.',
	'plugin_source' => 'fuente: ',
	'plugin_titre_automatique' => 'Instalación automática',
	'plugin_titre_automatique_ajouter' => 'Añadir plugins',
	'plugin_titre_installation' => 'Instalación del plugin @plugin@',
	'plugin_titre_modifier' => 'Mis plugins',
	'plugin_utilise_extension_php' => 'La extensión PHP del plugin @plugin@ debe estar en la versión @version@.',
	'plugin_utilise_php' => '@plugin@ debe estar en la versión @version@.',
	'plugin_utilise_plugin' => 'El plugin @plugin@ debe estar en la versión @version@.',
	'plugin_zip_active' => 'Continúe para activarlo',
	'plugin_zip_adresse' => 'indique aquí la dirección de un archivo zip de plugin a descargar, o también la dirección de una lista de plugins.',
	'plugin_zip_adresse_champ' => 'Dirección del plugin o de la lista ',
	'plugin_zip_content' => 'Contiene los siguientes archivos (@taille@),<br />que se instalarán en la carpeta <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'El archivo @zip@ se ha descomprimido e instalado.',
	'plugin_zip_installe_rep_finie' => 'El archivo @zip@ se ha descomprimido y se ha instalado en la carpeta @rep@',
	'plugin_zip_installer' => 'Ahora puede instalarlo.',
	'plugin_zip_telecharge' => 'Se ha descargado el archivo @zip@',
	'plugins_actif_aucun' => 'Ningún plugin activado.',
	'plugins_actif_un' => 'Un plugin activado.',
	'plugins_actifs' => '@count@ plugins activados.',
	'plugins_actifs_liste' => 'Activos',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'Un plugin disponible.',
	'plugins_disponibles' => '@count@ plugins disponibles.',
	'plugins_erreur' => 'Error en los plugins: @plugins@',
	'plugins_liste' => 'Lista de plugins',
	'plugins_liste_dist' => 'Plugins cerrados',
	'plugins_recents' => 'Plugins recientes.',
	'plugins_tous_liste' => 'Todos',
	'plugins_vue_hierarchie' => 'Jerarquía',
	'plugins_vue_liste' => 'Lista',
	'protocole_ldap' => 'Versión del protocolo:',

	// Q
	'queue_executer_maintenant' => 'Ejecutar ahora',
	'queue_info_purger' => 'Puede eliminar todas las tareas pendientes en segundo plano y restablecer la lista con las tareas periódicas',
	'queue_nb_jobs_in_queue' => '@nb@ tareas pendientes',
	'queue_next_job_in_nb_sec' => 'Siguiente tarea en @nb@ s',
	'queue_no_job_in_queue' => 'No hay tareas pendientes',
	'queue_one_job_in_queue' => '1 tarea pendiente',
	'queue_priorite_tache' => 'prioridad',
	'queue_purger_queue' => 'Restablecer la lista de tareas',
	'queue_titre' => 'Tareas en segundo plano',

	// R
	'repertoire_plugins' => 'Carpeta:',
	'required' => '(obligatorio)',

	// S
	'sans_heure' => 'sin hora',
	'statut_admin_restreint' => 'administrador restringido',
	'statut_webmestre' => 'webmaster',

	// T
	'tache_cron_asap' => 'Tarea CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Tarea CRON @function@ (cada @nb@ s)',
	'taille_cache_image' => 'Las imágenes calculadas automáticamente por SPIP (miniaturas de documentos, títulos presentados en forma gráfica, fórmulas matemáticas en formato TeX...) ocupan en el directorio @dir@ un total de @taille@.',
	'taille_cache_moins_de' => 'El tamaño de la cache es menor a @octets@.',
	'taille_cache_octets' => 'El tamaño de la caché es actualmente de @octets@.',
	'taille_cache_vide' => 'La cache está vacía.',
	'taille_repertoire_cache' => 'Tamaño de la carpeta cache',
	'text_article_propose_publication' => 'Artículo propuesto para su publicación.',
	'texte_acces_ldap_anonyme_1' => 'Algunos servidores LDAP no aceptan accesos anónimos. En ese caso debe especificar un identificador de acceso inicial para poder luego buscar información en el directorio. En la mayoría de los casos los campos siguientes pueden estar vacíos.',
	'texte_admin_effacer_01' => 'Este comando borra <i>TODO</i> el contenido de la base de datos, e incluye <i>todos</i> los accesos redactores y administradores. Después de ejecutarlo tendrá que volver a instalar SPIP, creando una nueva base al igual que un primer acceso de administración.', # MODIF
	'texte_adresse_annuaire_1' => '(Si su carpeta está instalada en la misma máquina que el sitio Web, se trata probablemente de "localhost").',
	'texte_ajout_auteur' => 'El siguiente autor ha sido añadido al artículo:',
	'texte_annuaire_ldap_1' => 'Si tiene un acceso a un directorio (LDAP), puede utilizarlo para importar automáticamente usuarios de SPIP.', # MODIF
	'texte_article_statut' => 'Este artículo está:',
	'texte_article_virtuel' => 'Artículo virtual',
	'texte_article_virtuel_reference' => '<b>Artículo virtual:</b> Artículo referenciado en su sitio SPIP, pero redirigido hacia otra URL. Para eliminar la redirección, borre la URL .',
	'texte_aucun_resultat_auteur' => 'Ningún resultado por "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Este sitio puede indicarle permanentemente la lista de personas conectadas, lo que permite intercambiar mensajes en directo. Además, puede decidir no aparecer en la lista (figura como «invisible» para los otros usuarios).', # MODIF
	'texte_auteurs' => 'LOS AUTORES',
	'texte_choix_base_1' => 'Eleja la base:',
	'texte_choix_base_2' => 'El servidor SQL contiene varias bases de datos.',
	'texte_choix_base_3' => '<b>Seleccione</b> aquí la que te fue atribuída por tu proveedor de hospedaje:',
	'texte_choix_table_prefix' => 'Prefijo de las tablas:',
	'texte_compte_element' => '@count@ elemento',
	'texte_compte_elements' => '@count@ elementos',
	'texte_conflit_edition_correction' => 'Por favor revise aquí debajo las diferencias entre las dos versiones del texto; también podrá copiar sus modificaciones, y luego volver a empezar.',
	'texte_connexion_mysql' => 'Consulte la información facilitada por su hospedaje: ahí debería encontrar el nombre del servidor de base de datos que le ofrece y las claves e identificador para conectarse.',
	'texte_contenu_article' => '(Contenido del artículo en pocas palabras)',
	'texte_contenu_articles' => 'Según el diseño de su sitio, puede decidir que algunos elementos de los artículos no sean utilizados. Utilice la siguiente lista para indicar qué elementos están disponibles.',
	'texte_crash_base' => 'Si su base de datos ha fallado, puede intentar una reparación automática. ',
	'texte_creer_rubrique' => 'Antes de poder escribir artículos,<br /> debe crear una sección.',
	'texte_date_creation_article' => 'FECHA DE CREACIÓN DEL ARTÍCULO:',
	'texte_date_creation_objet' => 'Fecha de creación:', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Fecha de redacción anterior:',
	'texte_date_publication_anterieure_nonaffichee' => 'No mostrar fecha de redacción anterior.',
	'texte_date_publication_article' => 'FECHA DE PUBLICACIÓN EN LÍNEA:',
	'texte_date_publication_objet' => 'Fecha de publicación en línea:',
	'texte_definir_comme_traduction_rubrique' => 'Esta rúbrica es una traducción de la rúbrica número :',
	'texte_descriptif_rapide' => 'Descripción rápida',
	'texte_effacer_base' => 'Borrar la base de datos SPIP',
	'texte_effacer_statistiques' => 'Borrar las estadísticas',
	'texte_en_cours_validation' => 'Los contenidos a continuación están a la espera de validación.',
	'texte_enrichir_mise_a_jour' => 'Puedes enriquecer el formato de tu texto utilizando "atajos tipográficos"',
	'texte_fichier_authent' => '<b>¿Debe SPIP crear los archivos especiales <tt>.htpasswd</tt>
 y <tt>.htpasswd-admin</tt> en la carpeta @dossier@?</b><p>
Estos archivos pueden servir para restringir el acceso a los autores y administradores en otros lugares de su sitio (programa externo de estadísticas, por ejemplo).<p>
Si no le ve utilidad, puede dejar esta opción con su valor por defecto (no crear los archivos).</p>', # MODIF
	'texte_informations_personnelles_1' => 'El sistema va a crear ahora un acceso personalizado al sitio.',
	'texte_informations_personnelles_2' => '(Nota: si se trata de una reinstalación, y su acceso todavía funciona, puede ',
	'texte_introductif_article' => '(Introducción del artículo)',
	'texte_jeu_caractere' => 'Se aconseja emplear para el sitio el alfabeto universal <tt>utf-8</tt>): permite visualizar textos en todos los idiomas, y ya no plantea problemas de compatibilidad con navegadores modernos.',
	'texte_jeu_caractere_3' => 'Su sitio está actualmente instalado en el juego de caracteres:',
	'texte_jeu_caractere_4' => 'Si no corresponde a la realidad de Sus datos (por ejemplo, después de una restauración de base de datos), o si <em>empieza este sitio</em> y desea hacerlo con otro juego de caracteres, indíquelo aquí:',
	'texte_login_ldap_1' => '(Dejar en blanco para un acceso anónimo, o indicar la ruta completa, por ejemplo "<tt>uid=perez, ou=users, dc=mi-dominio, dc=com</tt>".)',
	'texte_login_precaution' => '¡Atención! Éste es el nombre de usuario con el que está conectado actualmente.
Utilice este formulario con precaución...',
	'texte_messagerie_agenda' => 'Una mensajería permite a los redactores del sitio comunicarse entre ellos directamente en el espacio privado. Esta mensajería está asociada a una agenda.', # MODIF
	'texte_mise_a_niveau_base_1' => 'Acaba de actualizar los archivos de SPIP.
 Ahora se debe actualizar la base de datos del sitio.',
	'texte_modifier_article' => 'Modificar el artículo:',
	'texte_multilinguisme' => 'Si desea manejar objetos en varios idiomas, con una navegación compleja, puede agregar un menú de selección de idioma para esos objetos, en función de la organización de su sitio.',
	'texte_multilinguisme_trad' => 'También puede activar un sistema de gestión de enlaces entre las diferentes traducciones de ciertos objetos. ',
	'texte_non_compresse' => '<i>no comprimido</i> (tu servidor no soporta esta funcionalidad)',
	'texte_nouvelle_version_spip_1' => 'Ha instalado una versión nueva de SPIP.',
	'texte_nouvelle_version_spip_2' => 'Esta nueva versión necesita una actualización más completa que de costumbre. Si es webmaster del sitio, borre el archivo @connect@ y retome la instalación con el fin de actualizar los parámetros de conexión a la base de datos.<p> (NB: si ha olvidado los parámetros de conexión, eche un vistazo al archivo @connect@ antes de suprimirlo...)</p>',
	'texte_operation_echec' => 'Regrese a la página anterior, seleccione otra base o cree una nueva. Verifique la información facilitada por su proveedor de hospedaje.',
	'texte_plus_trois_car' => 'más de 3 caracteres',
	'texte_plusieurs_articles' => 'Se ha encontrado varios autores para "@cherche_auteur@":',
	'texte_port_annuaire' => '(En general, es adecuado el valor predeterminado)',
	'texte_presente_plugin' => 'Esta página lista los plugins disponibles en el sitio. Puede activar los plugins necesarios seleccionando la casilla correspondiente. ',
	'texte_proposer_publication' => 'Cuando su artículo esté terminado, <br /> puede proponer su publicación.',
	'texte_proxy' => 'En algunos casos (intranet, redes protegidas...), los sitios distantes (documentación de SPIP, sitios sindicados, etc.) no son accesibles más que através de un <i>proxy HTTP</i>. En ese caso, indique a continuación su dirección, bajo la forma <tt><html>http://proxy:8080</html></tt>. En general, se dejará esta casilla vacía.',
	'texte_publication_articles_post_dates' => '¿Qué comportamiento debe adoptar SPIP frente a los artículos cuya fecha de publicación ha sido fijada con un plazo futuro?',
	'texte_rappel_selection_champs' => '[Seleccione correctamente este campo]',
	'texte_recalcul_page' => 'Si desea recalcular una sola página utiliza el botón "Recalcular" en el espacio público.',
	'texte_recuperer_base' => 'Reparar la base de datos',
	'texte_reference_mais_redirige' => 'Artículo referenciado en su sitio y redirigido hacia otra URL.',
	'texte_requetes_echouent' => '<b>Cuando algunas peticiones SQL fallan sistemáticamente y sin razón aparente, es posible que sea debido a la base de datos en sí.</b><p>
Su servidor SQL es capaz de reparar sus tablas cuando fueron dañadas por accidente.  Puede intentar aquí esta reparación: si falla, conservE una copia del resultado, que posiblemente contenga indicios de lo que no funciona...</p><p>
Si el problema persiste, contacte a su hospedaje.</p>',
	'texte_selection_langue_principale' => 'A continuación puede seleccionar el «idioma principal» del sitio. Esta selección no obliga -¡afortunadamente!- a escribir los artículos en el idioma elegido, pero permite determinar:
<ul><li> el formato predeterminado de las fechas en el sitio público;</li>
<li> la naturaleza del motor tipográfico que SPIP debe utilizar para reproducir los textos;</li>
<li> el idioma utilizado en los formularios del sitio público;</li>
<li> el idioma predeterminado para el espacio privado.</li></ul>',
	'texte_sous_titre' => 'Subtítulo',
	'texte_statistiques_visites' => '(Barras oscuras: domingo / curva oscura: evolución del promedio)',
	'texte_statut_attente_validation' => 'En espera de validación',
	'texte_statut_publies' => 'Publicados',
	'texte_statut_refuses' => 'Rechazados',
	'texte_suppression_fichiers' => 'Utilice esta operación para suprimir todos los archivos presentes en la caché de SPIP. Esto permite, por ejemplo, forzar la actualización de todas las páginas si se hicieron importantes modificaciones gráficas o de estructura del sitio.',
	'texte_sur_titre' => 'Antetítulo',
	'texte_table_ok' => ': esta tabla está bien.',
	'texte_tentative_recuperation' => 'Tentativa de reparación.',
	'texte_tenter_reparation' => 'Intentar la reparación de la base de datos.',
	'texte_test_proxy' => 'Para ensayar este "proxy" indique aquí la URL del sitio.',
	'texte_titre_02' => 'Título',
	'texte_titre_obligatoire' => '<b>Título</b> [Obligatorio]',
	'texte_travail_article' => '@nom_auteur_modif@ ha trabajado sobre este artículo hace @date_diff@ minutos.',
	'texte_travail_collaboratif' => 'Es frecuente que varios redactores y redactoras trabajen sobre el mismo artículo, el sistema puede mostrar los artículos recientemente «abiertos» para  evitar las modificaciones simultáneas.
 Esta opción está desactivada por omisión para evitar mostrar mensajes de advertencia intempestivos.', # MODIF
	'texte_vide' => 'vacío',
	'texte_vider_cache' => 'Vaciar la caché',
	'titre_admin_tech' => 'Mantenimiento técnico',
	'titre_ajouter_un_auteur' => 'Añadir una autora',
	'titre_ajouter_un_mot' => 'Añadir una palabra-clave',
	'titre_cadre_afficher_article' => 'Mostrar los artículos',
	'titre_cadre_afficher_traductions' => 'Mostrar el estado de las traducciones para los idiomas siguientes:',
	'titre_cadre_ajouter_auteur' => 'Añadir un autor',
	'titre_cadre_interieur_rubrique' => 'Al interior de la sección',
	'titre_cadre_numero_auteur' => 'AUTOR NÚMERO',
	'titre_cadre_numero_objet' => '@objet@ NÚMERO:',
	'titre_cadre_signature_obligatoire' => '<b>Firma</b> [Obligatoria]<br />',
	'titre_config_contenu_notifications' => 'Notificaciones',
	'titre_config_contenu_prive' => 'En el espacio privado',
	'titre_config_contenu_public' => 'En el sitio público',
	'titre_config_fonctions' => 'Configuración del sitio',
	'titre_config_langage' => 'Configuración del idioma',
	'titre_configuration' => 'Configuración del sitio',
	'titre_configurer_preferences' => 'Sus preferencias',
	'titre_configurer_preferences_menus' => 'Configurer tus preferencias de menus',
	'titre_conflit_edition' => 'Conflicto durante la edición',
	'titre_connexion_ldap' => 'Opciones: <b>Tu conexión LDAP</b>',
	'titre_groupe_mots' => 'Grupo de palabras',
	'titre_identite_site' => 'Identidad del sitio',
	'titre_langue_article' => 'Idioma del artículo',
	'titre_langue_rubrique' => 'Idioma de la sección',
	'titre_langue_trad_article' => 'IDIOMA Y TRADUCCIONES DEL ARTÍCULO',
	'titre_les_articles' => 'Los artículos',
	'titre_messagerie_agenda' => 'Mensajería y agenda',
	'titre_naviguer_dans_le_site' => 'Navegar por el sitio...',
	'titre_nouvelle_rubrique' => 'Nueva sección',
	'titre_numero_rubrique' => 'SECCIÓN NÚMERO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Los artículos',
	'titre_page_articles_tous' => 'Todo el sitio',
	'titre_page_calendrier' => 'Calendario @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configuración del sitio',
	'titre_page_delete_all' => 'Supresión total e irreversible',
	'titre_page_recherche' => 'Resultados de la búsqueda @recherche@',
	'titre_page_statistiques_referers' => 'Estadísticas (enlaces entrantes)',
	'titre_page_upgrade' => 'Actualización de SPIP',
	'titre_preference_menus_favoris' => 'Menus favoritos',
	'titre_publication_articles_post_dates' => 'Publicación de los artículos con fecha posterior',
	'titre_reparation' => 'Reparación',
	'titre_suivi_petition' => 'Gestión de las peticiones',
	'tls_ldap' => 'Transport Layer Security:',
	'trad_article_traduction' => 'Todas las versiones de este artículo:',
	'trad_delier' => 'Dejar de ligar a estas traducciones ',
	'trad_lier' => 'Este artículo es una traducción del artículo número:',
	'trad_new' => 'Escribir una nueva traducción',

	// U
	'utf8_convert_erreur_orig' => 'Error: el juego de caracteres no está soportado.',

	// V
	'version' => 'Versión:',
];
